Python Package for WV detail”
=============================

Link: https://www.youtube.com/

PyPi: https://pypi.org/project/mynameiswv/

Hello, this is the package for showing WV detail. You will able to see
my Github and Youtube as well as art.

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install mynameiswv

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from mynameiswv import WV

   wv = WV() #class notification
   wv.show_name() #show name
   wv.show_youtube() #show youtube
   wv.show_page() #show page
   wv.about() #show others
   wv.show_art() #show art

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer

YouTube: https://www.youtube.com/UncleEngineer
